@@ -13,7 +13,10 @@ module Grape
 
       def [](name)
         return @froozen_values[name] if @froozen_values.key? name
-        [@inherited_values[name], @new_values[name]].compact.flatten(1)
+        value = [@inherited_values[name], @new_values[name]]
+        value.compact!
+        value.flatten!(1)
+        value
       end
 
       def []=(name, value)
@@ -45,7 +48,7 @@ module Grape
       def initialize_copy(other)
         super
         self.inherited_values = other.inherited_values
-        self.new_values = other.new_values.deep_dup
+        self.new_values = other.new_values.dup
       end
     end
   end
