@@ -941,4 +941,87 @@ describe Grape::Endpoint do
       expect(last_response.body).to eq File.read(__FILE__)
     end
   end
+
+  context 'validation errors' do
+    before do
+      subject.before do
+        header['Access-Control-Allow-Origin'] = '*'
+      end
+      subject.params do
+        requires :id, type: String
+      end
+      subject.get do
+        'should not get here'
+      end
+    end
+
+    it 'returns the errors, and passes headers' do
+      get '/'
+      expect(last_response.status).to eq 400
+      expect(last_response.body).to eq 'id is missing'
+      expect(last_response.headers['Access-Control-Allow-Origin']).to eq('*')
+    end
+  end
+
+  context 'instrumentation' do
+    before do
+      subject.before do
+        # Placeholder
+      end
+      subject.get do
+        'hello'
+      end
+
+      @events = []
+      @subscriber = ActiveSupport::Notifications.subscribe(/grape/) do |*args|
+        @events << ActiveSupport::Notifications::Event.new(*args)
+      end
+    end
+
+    after do
+      ActiveSupport::Notifications.unsubscribe(@subscriber)
+    end
+
+    it 'notifies AS::N' do
+      get '/'
+
+      # In order that the events finalized (time each block ended)
+      expect(@events).to contain_exactly(
+        have_attributes(name: 'endpoint_run_filters.grape', payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       filters: a_collection_containing_exactly(an_instance_of(Proc)),
+                                                                       type: :before }),
+        have_attributes(name: 'endpoint_run_filters.grape', payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       filters: [],
+                                                                       type: :before_validation }),
+        have_attributes(name: 'endpoint_run_filters.grape', payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       filters: [],
+                                                                       type: :after_validation }),
+        have_attributes(name: 'endpoint_render.grape',      payload: { endpoint: an_instance_of(Grape::Endpoint) }),
+        have_attributes(name: 'endpoint_run_filters.grape', payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       filters: [],
+                                                                       type: :after }),
+        have_attributes(name: 'endpoint_run.grape',         payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       env: an_instance_of(Hash) })
+      )
+
+      # In order that events were initialized
+      expect(@events.sort_by(&:time)).to contain_exactly(
+        have_attributes(name: 'endpoint_run.grape',         payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       env: an_instance_of(Hash) }),
+        have_attributes(name: 'endpoint_run_filters.grape', payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       filters: a_collection_containing_exactly(an_instance_of(Proc)),
+                                                                       type: :before }),
+        have_attributes(name: 'endpoint_run_filters.grape', payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       filters: [],
+                                                                       type: :before_validation }),
+        have_attributes(name: 'endpoint_run_filters.grape', payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       filters: [],
+                                                                       type: :after_validation }),
+        have_attributes(name: 'endpoint_render.grape',      payload: { endpoint: an_instance_of(Grape::Endpoint) }),
+        have_attributes(name: 'endpoint_run_filters.grape', payload: { endpoint: an_instance_of(Grape::Endpoint),
+                                                                       filters: [],
+                                                                       type: :after })
+      )
+    end
+  end
 end
